@@ -20,8 +20,13 @@ def procdf(function,allvars,procaxis,dimidx=0):
             dtotmp, outcoords = procdf(function,allvarsin,procaxis,dimidx=dimidx+1)
             dataout.append(dtotmp)
     else:
-        #print(allvars)
-        dataouttemp = function(allvars)
+        # workaround for memory leak when just running  'dataouttemp = function(allvars)' in case of netcdf file references
+        allvarstmp = []
+        for evar in allvars:
+            allvarstemp.append(array(evar))
+        dataouttemp = function(allvarstemp)
+        # end workaround
+
         if (type(dataouttemp).__name__ == 'list'):
             dataout = dataouttemp[0]
             outcoords = dataouttemp[1]
